@@ -1,4 +1,5 @@
 use crate::{
+    expression::{def_buffer, def_package, expression_opcode},
     misc::{arg_obj, local_obj},
     name_object::{name_seg, name_string},
     namespace::{AmlName, LevelType},
@@ -6,7 +7,6 @@ use crate::{
     parser::{
         choice,
         comment_scope,
-        make_parser_concrete,
         take,
         take_to_end_of_pkglength,
         take_u16,
@@ -18,8 +18,7 @@ use crate::{
         Propagate,
     },
     pkg_length::{pkg_length, PkgLength},
-    type1::type1_opcode,
-    type2::{def_buffer, def_package, type2_opcode},
+    statement::statement_opcode,
     value::{AmlValue, FieldFlags, MethodCode, MethodFlags, RegionSpace},
     AmlContext,
     AmlError,
@@ -57,7 +56,7 @@ where
     'c: 'a,
 {
     /*
-     * TermObj := NamespaceModifierObj | NamedObj | Type1Opcode | Type2Opcode
+     * TermObj := NamespaceModifierObj | NamedObj | StatementOpcode | ExpressionOpcode
      */
     comment_scope(
         DebugVerbosity::AllScopes,
@@ -65,8 +64,8 @@ where
         choice!(
             namespace_modifier().map(|()| Ok(None)),
             named_obj().map(|()| Ok(None)),
-            type1_opcode().map(|()| Ok(None)),
-            type2_opcode().map(|value| Ok(Some(value)))
+            statement_opcode().map(|()| Ok(None)),
+            expression_opcode().map(|value| Ok(Some(value)))
         ),
     )
 }
@@ -193,7 +192,8 @@ where
             "DefCreateBitField",
             term_arg().then(term_arg()).then(name_string()).map_with_context(
                 |((source, index), name), context| {
-                    let source_data: Arc<Vec<u8>> = try_with_context!(context, source.as_buffer(context)).clone();
+                    let source_data: Arc<spinning_top::Spinlock<Vec<u8>>> =
+                        try_with_context!(context, source.as_buffer(context)).clone();
                     let index = try_with_context!(context, index.as_integer(context));
 
                     try_with_context!(
@@ -227,7 +227,8 @@ where
             "DefCreateByteField",
             term_arg().then(term_arg()).then(name_string()).map_with_context(
                 |((source, index), name), context| {
-                    let source_data: Arc<Vec<u8>> = try_with_context!(context, source.as_buffer(context)).clone();
+                    let source_data: Arc<spinning_top::Spinlock<Vec<u8>>> =
+                        try_with_context!(context, source.as_buffer(context)).clone();
                     let index = try_with_context!(context, index.as_integer(context));
 
                     try_with_context!(
@@ -261,7 +262,8 @@ where
             "DefCreateWordField",
             term_arg().then(term_arg()).then(name_string()).map_with_context(
                 |((source, index), name), context| {
-                    let source_data: Arc<Vec<u8>> = try_with_context!(context, source.as_buffer(context)).clone();
+                    let source_data: Arc<spinning_top::Spinlock<Vec<u8>>> =
+                        try_with_context!(context, source.as_buffer(context)).clone();
                     let index = try_with_context!(context, index.as_integer(context));
 
                     try_with_context!(
@@ -295,7 +297,8 @@ where
             "DefCreateDWordField",
             term_arg().then(term_arg()).then(name_string()).map_with_context(
                 |((source, index), name), context| {
-                    let source_data: Arc<Vec<u8>> = try_with_context!(context, source.as_buffer(context)).clone();
+                    let source_data: Arc<spinning_top::Spinlock<Vec<u8>>> =
+                        try_with_context!(context, source.as_buffer(context)).clone();
                     let index = try_with_context!(context, index.as_integer(context));
 
                     try_with_context!(
@@ -329,7 +332,8 @@ where
             "DefCreateQWordField",
             term_arg().then(term_arg()).then(name_string()).map_with_context(
                 |((source, index), name), context| {
-                    let source_data: Arc<Vec<u8>> = try_with_context!(context, source.as_buffer(context)).clone();
+                    let source_data: Arc<spinning_top::Spinlock<Vec<u8>>> =
+                        try_with_context!(context, source.as_buffer(context)).clone();
                     let index = try_with_context!(context, index.as_integer(context));
 
                     try_with_context!(
@@ -364,7 +368,8 @@ where
             "DefCreateField",
             term_arg().then(term_arg()).then(term_arg()).then(name_string()).map_with_context(
                 |(((source, index), num_bits), name), context| {
-                    let source_data: Arc<Vec<u8>> = try_with_context!(context, source.as_buffer(context)).clone();
+                    let source_data: Arc<spinning_top::Spinlock<Vec<u8>>> =
+                        try_with_context!(context, source.as_buffer(context)).clone();
                     let index = try_with_context!(context, index.as_integer(context));
                     let num_bits = try_with_context!(context, num_bits.as_integer(context));
 
@@ -828,7 +833,7 @@ where
     'c: 'a,
 {
     /*
-     * TermArg := Type2Opcode | DataObject | ArgObj | LocalObj
+     * TermArg := ExpressionOpcode | DataObject | ArgObj | LocalObj
      */
     comment_scope(
         DebugVerbosity::AllScopes,
@@ -841,7 +846,7 @@ where
             local_obj().map_with_context(|local_num, context| {
                 (Ok(try_with_context!(context, context.local(local_num)).clone()), context)
             }),
-            make_parser_concrete!(type2_opcode())
+            expression_opcode()
         ),
     )
 }
@@ -931,7 +936,7 @@ where
         choice!(
             ext_opcode(opcode::EXT_REVISION_OP).map(|_| Ok(AmlValue::Integer(crate::AML_INTERPRETER_REVISION))),
             const_parser,
-            make_parser_concrete!(def_buffer())
+            def_buffer()
         ),
     )
 }
